@@ -117,6 +117,10 @@ class TestGenerator(object):
         #modified so that we only retest things that change.
         files = {}
         for needk in needs:
+            #Ignore references to fortpy since we include it automatically.
+            if needk == "fortpy":
+                continue
+
             needed = self.parser.modules[needk]
             moddate = modification_date(needed.filepath)
             #We also consider a module altered if its XML file has changed since
